coalib.processes.communication package — coala 0.11.0.rc1 documentation

# coalib.processes.communication package

## Submodules

## coalib.processes.communication.LogMessage module

class `coalib.processes.communication.LogMessage.` `LogMessage`(log_level, *messages, *, delimiter=' ', timestamp=None)

  Bases: `object`

  `to_string_dict`()

    Makes a dictionary which has all keys and values as strings and contains all the data that the LogMessage has.

    Returns: | Dictionary with keys and values as string.

## Module contents